@@ -8,8 +8,8 @@ from statistics import stdev
 from datetime import date, timedelta, datetime
 import time
 import requests
-import threading
-from threading import Timer, Event, Thread
+#import threading
+#from threading import Timer, Event, Thread
 import json
 
 
@@ -65,11 +65,11 @@ class Isin:
 def Create_isin_object(isn):
     return Isin(isn)
 
-
+"""
 #The Class to repeat a function as threading module every n seconds
 class RepeatedTimer:
 
-    """Repeat `function` every `interval` seconds."""
+#Repeat `function` every `interval` seconds.
 
     def __init__(self, interval, function, *args, **kwargs):
         self.interval = interval
@@ -98,6 +98,7 @@ def Repeat_Function(interval, function, *args, **kwargs):
     
 # What about stopping a function?
 
+"""
 # Getting StockWatch data
 
 def TSE_Close_Daily(bourse_id):
